Cherry-pick and revert operations.
Structs
- Cherrypick
- Cherry-pick a commit onto the working directory and index.
- Cherrypick
Commit - Cherry-pick a commit as a tree merge (without touching the working directory).
- Cherrypick
Conflict Output - Cherrypick
Output - Revert
- Revert a commit onto the working directory and index.
- Revert
Commit - Revert a commit as a tree merge (without touching the working directory).
- Revert
Output