pub struct CommitCreate { /* private fields */ }Expand description
Create a new commit on HEAD.
Stages the current index as a tree, creates a commit with the given message and author, and updates HEAD to point to the new commit.
Examples
use ironflow_ops_git::commit::CommitCreate;
use ironflow_core::operation::Operation;
let op = CommitCreate::new("/path/to/repo", "Initial commit", "Alice", "alice@example.com");
assert_eq!(op.kind(), "git");Implementations
Sourceimpl CommitCreate
impl CommitCreate
Sourcepub fn new(
repo_path: impl Into<PathBuf>,
message: impl Into<String>,
author_name: impl Into<String>,
author_email: impl Into<String>,
) -> Self
pub fn new( repo_path: impl Into<PathBuf>, message: impl Into<String>, author_name: impl Into<String>, author_email: impl Into<String>, ) -> Self
Create a new commit operation.
Sourcepub async fn run(
&self,
_ctx: &OperationContext,
) -> Result<CommitOutput, OperationError>
pub async fn run( &self, _ctx: &OperationContext, ) -> Result<CommitOutput, OperationError>
Execute and return a typed result.