Module diff

Module diff 

Diff operations.

Structs

DiffApply
Apply a diff to the working directory or index.
DiffApplyOutput
Output of DiffApply.
DiffDelta
A single delta entry in a diff.
DiffFindSimilar
Find renamed/copied files in a diff.
DiffIndexToWorkdir
Diff between the index and the working directory.
DiffOutput
Output of diff operations that return full diff info.
DiffStats
Get diff statistics.
DiffStatsOutput
Output of DiffStats.
DiffTreeToIndex
Diff between a tree and the index.
DiffTreeToTree
Diff between two trees.