Graph operations (ahead/behind, descendant, describe).
Structs
- Graph
Ahead Behind - Count commits ahead and behind between two references.
- Graph
Ahead Behind Output - Graph
Descendant Of - Check if a commit is a descendant of another.
- Graph
Descendant OfOutput - Graph
Describe - Describe a commit using the most recent tag reachable from it.
- Graph
Describe Output