Module index

Module index 

Index / staging area operations.

Structs

IndexAdd
Add a single file to the index.
IndexAddAll
Add all files matching a pathspec to the index.
IndexPathOutput
IndexPathspecsOutput
IndexRemove
Remove a file from the index.
IndexRemoveAll
Remove all files matching a pathspec from the index.
IndexUpdateAll
Update all tracked files in the index.
IndexUpdateAllOutput
IndexWriteTree
Write the index as a tree object.
IndexWriteTreeOutput