Module cherrypick

Module cherrypick 

Cherry-pick and revert operations.

Structs

Cherrypick
Cherry-pick a commit onto the working directory and index.
CherrypickCommit
Cherry-pick a commit as a tree merge (without touching the working directory).
CherrypickConflictOutput
CherrypickOutput
Revert
Revert a commit onto the working directory and index.
RevertCommit
Revert a commit as a tree merge (without touching the working directory).
RevertOutput