Module graph

Module graph 

Graph operations (ahead/behind, descendant, describe).

Structs

GraphAheadBehind
Count commits ahead and behind between two references.
GraphAheadBehindOutput
GraphDescendantOf
Check if a commit is a descendant of another.
GraphDescendantOfOutput
GraphDescribe
Describe a commit using the most recent tag reachable from it.
GraphDescribeOutput