Index / staging area operations.
Structs
- Index
Add - Add a single file to the index.
- Index
AddAll - Add all files matching a pathspec to the index.
- Index
Path Output - Index
Pathspecs Output - Index
Remove - Remove a file from the index.
- Index
Remove All - Remove all files matching a pathspec from the index.
- Index
Update All - Update all tracked files in the index.
- Index
Update AllOutput - Index
Write Tree - Write the index as a tree object.
- Index
Write Tree Output